@@ -4,13 +4,15 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 use base qw/Import::Export/;
 
 our %EX = (
         const => [qw/all/],
-	make_readonly => [qw/all/]
+	make_readonly => [qw/all/],
+	unmake_readonly => [qw/all/],
+	is_readonly => [qw/all/],
 );
 
 require XSLoader;
@@ -26,7 +28,7 @@ Const::XS - Facility for creating read-only scalars, arrays, hashes
 
 =head1 VERSION
 
-Version 0.11
+Version 0.12
 
 =cut
 
@@ -65,7 +67,7 @@ Version 0.11
 
 =head2 const
 
-This is the one of two functions of this module. It takes a scalar, array or hash lvalue as the first argument, and a list of one or more values depending on the type of the first argument as the value for the variable. It will set the variable to that value and subsequently make it readonly. Arrays and hashes will be made deeply readonly.
+This is the one of four functions of this module. It takes a scalar, array or hash lvalue as the first argument, and a list of one or more values depending on the type of the first argument as the value for the variable. It will set the variable to that value and subsequently make it readonly. Arrays and hashes will be made deeply readonly.
 
 	const my %factory => (
 		workers => 5,
@@ -97,6 +99,26 @@ Please note that if you call make_readonly on struct directly it will make that
 	$ref->{d}; # errors
 	$ref = { new => 1 };  # is okay
 
+=head2 unmake_readonly
+
+The third function exported by this module is unmake_readonly. It will take a perl variable that has been through make_readonly and deeply make it writeable again.
+
+	my $string = "abc";
+	make_readonly($string);
+	$string = 'def'; # errors
+	unmake_readonly($string);
+	$string = 'def'; # is okay
+
+=head2 is_readonly
+
+The fourth function exported by this module is is_readonly. It will deeply check a reference to see if it is readonly.
+
+	my $string = "abc";
+	is_readonly($string); # 0;
+	make_readonly($string);
+	is_readonly($string); # 1;
+	
+
 =head2 BENCHMARK
 
 	use Benchmark qw(:all);
